User Guide
==========

| The User Guide goes through the available features in WaloViz. For newcomers, quick introduction to WaloViz can be found in our `Getting Started Guide <../getting-started.html>`_.
| If you are looking for a deep dive into the API, try our `Reference Manual <../reference-manual.html>`_.

Feature guides
--------------

| These user guides provide an overview of the features you might find useful in WaloViz:

`Basic Usage <01-basic-usage.html>`_
    The most simple and useful ways to use WaloViz.

`Overlaying Data <02-overlaying-data.html>`_
    Add curves overlayed on the player, good for time-aligned visualizations such as a waveform.

`Responsiveness and Size <03-responsiveness-and-size.html>`_
    Control the size ot your player and customize the responsiveness to your personal needs.

`Advanced Options <04-advanced-options.html>`_
    Modify the WaloViz player with nuanced options and features to your specific use case.

`The Player <05-the-player.html>`_
    Learn all about the hidden features of the WaloViz player, and get more out of it.

.. toctree::
    :titlesonly:
    :hidden:
    :maxdepth: 2

    Basic Usage <01-basic-usage>
    Overlaying Data <02-overlaying-data>
    Responsiveness and Size <03-responsiveness-and-size>
    Advanced Options <04-advanced-options>
    The Player <05-the-player>
